NanoPy Scan

### Latest Block

--
Syncing...

### Transactions

--
Total indexed

### TPS

--
Last 60 seconds

### Addresses

--
Unique addresses

## Latest Blocks

View all

Block | Validator | Txs | Time
--- | --- | --- | ---
Loading...

## Latest Transactions

View all

Tx Hash | From | Value
--- | --- | ---
Loading...

## All Blocks

0 blocks

Block | Hash | Validator | Txs | Gas Used | Time
--- | --- | --- | --- | --- | ---
Loading...

## All Transactions

0 transactions

Tx Hash | Block | From | To | Value | Status
--- | --- | --- | --- | --- | ---
Loading...

## Validators

PoS Consensus

# | Address | Blocks Produced | Last Block
--- | --- | --- | ---
Loading...

# Network Status

### Network Health

--
Checking...

### Node Status

--
--

### Peers

--
Connected peers

### Last Block

--
--

## Node Information

Loading...

## Indexer Status

Loading...

# Block #--

Loading...

## Block Transactions

Tx Hash | From | To | Value | Status
--- | --- | --- | --- | ---
Loading...

# Transaction

Loading...

# Address

## Transactions

Tx Hash | Block | From | To | Value
--- | --- | --- | --- | ---
Loading...